@@ -4,16 +4,13 @@
 //! Currently only implemented with Wolfram's Rule 30.
 //!
 
-use std::env;
 use std::process;
 
+use clap::Parser;
 use cell_sim::Config;
 
 fn main() {
-    let config = Config::new(env::args()).unwrap_or_else(|err| {
-        eprintln!("Problem: {}", err);
-        process::exit(1);
-    });
+    let config = Config::parse();
 
     if let Err(e) = cell_sim::run(config) {
         eprintln!("Problem: {}", e);
